==> jc-1.4.0.tar.gz: scm/scmOutputStream.h <==
// class scm.scmOutputStream

// class file dependencies
// @dep_class 4bcb90cdc10424cf java_io_DataOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 51f24105fb854a84 scm_scmOutputStream

// header file dependencies
// @dep_header java_io_DataOutputStream

#include "java/io/DataOutputStream.h"

#ifndef _JC_scm_scmOutputStream_H_
#define _JC_scm_scmOutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_scm_scmOutputStream$sub_refs	_jc_scm_scmOutputStream$sub_refs;
typedef struct _jc_scm_scmOutputStream$sub_nonrefs	_jc_scm_scmOutputStream$sub_nonrefs;
typedef struct _jc_scm_scmOutputStream$refs	_jc_scm_scmOutputStream$refs;
typedef struct _jc_scm_scmOutputStream$nonrefs	_jc_scm_scmOutputStream$nonrefs;
typedef struct _jc_scm_scmOutputStream$object	_jc_scm_scmOutputStream$object;

typedef const struct _jc_scm_scmOutputStream$vmethods	_jc_scm_scmOutputStream$vmethods;
typedef const struct _jc_scm_scmOutputStream$vtable	_jc_scm_scmOutputStream$vtable;
typedef const struct _jc_scm_scmOutputStream$vtype	_jc_scm_scmOutputStream$vtype;

// Constructors
extern void _jc_scm_scmOutputStream$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_scmOutputStream$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_scm_scmOutputStream$vmethods {
};

// Vtable
struct _jc_scm_scmOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_io_DataOutputStream$vmethods	java_io_DataOutputStream;
	_jc_scm_scmOutputStream$vmethods	scm_scmOutputStream;
};

// Vtype
struct _jc_scm_scmOutputStream$vtype {
	_jc_type			type;
	_jc_scm_scmOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmOutputStream$refs {
    _jc_scm_scmOutputStream$sub_refs	scm_scmOutputStream;
    _jc_java_io_DataOutputStream$sub_refs	java_io_DataOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_io_DataOutputStream$sub_nonrefs	java_io_DataOutputStream;
    _jc_scm_scmOutputStream$sub_nonrefs	scm_scmOutputStream;
};

// Object instance structure
struct _jc_scm_scmOutputStream$object {
	_jc_scm_scmOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmOutputStream$vtype	*vtype;
	_jc_scm_scmOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmOutputStream$vtype _jc_scm_scmOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmOutputStream$class_object;

#endif	/* _JC_scm_scmOutputStream_H_ */

==> jc-1.4.6.tar.gz: scm/scmOutputStream.h <==
// class scm.scmOutputStream

// class file dependencies
// @dep_class d755b96203d8fbaf java_io_DataOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 51f24105fb854a84 scm_scmOutputStream

// header file dependencies
// @dep_header java_io_DataOutputStream

#include "java/io/DataOutputStream.h"

#ifndef _JC_scm_scmOutputStream_H_
#define _JC_scm_scmOutputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_scm_scmOutputStream$sub_refs	_jc_scm_scmOutputStream$sub_refs;
typedef struct _jc_scm_scmOutputStream$sub_nonrefs	_jc_scm_scmOutputStream$sub_nonrefs;
typedef struct _jc_scm_scmOutputStream$refs	_jc_scm_scmOutputStream$refs;
typedef struct _jc_scm_scmOutputStream$nonrefs	_jc_scm_scmOutputStream$nonrefs;
typedef struct _jc_scm_scmOutputStream$object	_jc_scm_scmOutputStream$object;

typedef const struct _jc_scm_scmOutputStream$vmethods	_jc_scm_scmOutputStream$vmethods;
typedef const struct _jc_scm_scmOutputStream$vtable	_jc_scm_scmOutputStream$vtable;
typedef const struct _jc_scm_scmOutputStream$vtype	_jc_scm_scmOutputStream$vtype;

// Constructors
extern void _jc_scm_scmOutputStream$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_scmOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_scm_scmOutputStream$vmethods {
};

// Vtable
struct _jc_scm_scmOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_io_DataOutputStream$vmethods	java_io_DataOutputStream;
	_jc_scm_scmOutputStream$vmethods	scm_scmOutputStream;
};

// Vtype
struct _jc_scm_scmOutputStream$vtype {
	_jc_type			type;
	_jc_scm_scmOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmOutputStream$refs {
    _jc_scm_scmOutputStream$sub_refs	scm_scmOutputStream;
    _jc_java_io_DataOutputStream$sub_refs	java_io_DataOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_io_DataOutputStream$sub_nonrefs	java_io_DataOutputStream;
    _jc_scm_scmOutputStream$sub_nonrefs	scm_scmOutputStream;
};

// Object instance structure
struct _jc_scm_scmOutputStream$object {
	_jc_scm_scmOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmOutputStream$vtype	*vtype;
	_jc_scm_scmOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmOutputStream$vtype _jc_scm_scmOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmOutputStream$class_object;

#endif	/* _JC_scm_scmOutputStream_H_ */
